@@ -14,6 +14,11 @@
  * limitations under the License.
  */
 
+/**
+ * @file globus_error_string.h
+ * @brief Error Object Containing a String
+ */
+
 #ifndef GLOBUS_ERROR_STRING_H
 #define GLOBUS_ERROR_STRING_H
 
@@ -21,7 +26,9 @@
 #include "globus_error.h"
 
  
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 extern const globus_object_type_t GLOBUS_ERROR_TYPE_STRING_DEFINITION;
 
@@ -48,8 +55,8 @@ globus_error_initialize_string(
     const char *			fmt,
     va_list				ap);
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* GLOBUS_ERROR_STRING_H */
-
-
